/* 
 * gnome-keyring
 * 
 * Copyright (C) 2008 Stefan Walter
 * 
 * This program is free software; you can redistribute it and/or modify 
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *  
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *  
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.  
 */

#ifndef __GCK_TYPES_H__
#define __GCK_TYPES_H__

typedef struct _GckAesKey GckAesKey;
typedef struct _GckCertificate GckCertificate;
typedef struct _GckCertificateKey GckCertificateKey;
typedef struct _GckCertificateTrust GckCertificateTrust;
typedef struct _GckCredential GckCredential;
typedef struct _GckDhKey GckDhKey;
typedef struct _GckDhPrivateKey GckDhPrivateKey;
typedef struct _GckDhPublicKey GckDhPublicKey;
typedef struct _GckFactory GckFactory;
typedef struct _GckManager GckManager;
typedef struct _GckModule GckModule;
typedef struct _GckNullKey GckNullKey;
typedef struct _GckObject GckObject;
typedef struct _GckPrivateXsaKey GckPrivateXsaKey;
typedef struct _GckPublicXsaKey GckPublicXsaKey;
typedef struct _GckSecret GckSecret;
typedef struct _GckSecretKey GckSecretKey;
typedef struct _GckSession GckSession;
typedef struct _GckSessionPrivateKey GckSessionPrivateKey;
typedef struct _GckSessionPublicKey GckSessionPublicKey;
typedef struct _GckSexp GckSexp;
typedef struct _GckSexpKey GckSexpKey;
typedef struct _GckStore GckStore;
typedef struct _GckTimer GckTimer;
typedef struct _GckTransaction GckTransaction;

#endif /* __GCK_TYPES_H__ */
